@@ -1,5 +1,6 @@
 from pyspark.sql import SparkSession, DataFrame
-from dataclasses import dataclass, field
+from dataclasses import dataclass
+from typing import List
 
 try:
     from pyspark.dbutils import DBUtils
@@ -78,13 +79,11 @@ class DatabricksConfig:
         self.append_comma = append_comma
 
 
-@dataclass
+@dataclass()
 class OSPaths:
-    hadoop_home: str = field(default=r"C:\Files\ScoopApps\apps\hadoop-winutils\current")
-    pyspark_python: str = field(
-        default=r"C:\Files\ScoopApps\apps\python\current\python.exe"
-    )
-    java_home: str = field(default=r"C:\Files\ScoopApps\apps\temurin8-jdk\current")
+    hadoop_home: str = "C:\\Files\\ScoopApps\\apps\\hadoop-winutils\\current\\"
+    pyspark_python: str = "C:\\Files\\ScoopApps\\apps\\python38\\current\\python.exe"
+    java_home: str = "C:\\Files\\ScoopApps\\apps\\temurin8-jdk\\current\\"
 
 
 def jupyter_support_config() -> None:
@@ -246,24 +245,22 @@ def set_env(spark: SparkSession, profile_alias: str) -> None:
 def set_os_paths(
     hadoop_home: str = "", java_home: str = "", pyspark_python: str = ""
 ) -> None:
-    osp = OSPaths(
-        hadoop_home=hadoop_home, java_home=java_home, pyspark_python=pyspark_python
-    )
-
     """A function for setting OS environment variables, required by spark"""
-    hadoop_home = osp.hadoop_home
+    osp = OSPaths()
+    hadoop_home = hadoop_home if hadoop_home != "" else osp.hadoop_home
+    java_home = java_home if java_home != "" else osp.java_home
+    pyspark_python = pyspark_python if pyspark_python != "" else osp.pyspark_python
+
     if not (Path(hadoop_home).exists()):
         print(f"HADOOP_HOME was not set - the path {hadoop_home} was not found")
         hadoop_home = input("Enter an alternative path: ")
         print(f"HADOOP_HOME set to {hadoop_home}")
 
-    pyspark_python = osp.pyspark_python
     if not (Path(pyspark_python).exists()):
         print(f"PYSPARK_PYTHON was not set - the path {pyspark_python} was not found")
         pyspark_python = input("Enter an alternative path: ")
         print(f"PYSPARK_PYTHON set to {pyspark_python}")
 
-    java_home = osp.java_home
     if not (Path(java_home).exists()):
         print(f"JAVA_HOME was not set - the path {java_home} was not found")
         java_home = input("Enter an alternative path: ")
@@ -312,7 +309,7 @@ def get_entity_columns(databricks_config: DatabricksConfig, df: DataFrame) -> No
         __print_error_msg(ex)
 
 
-def __get_childitem_old(
+def get_childitems_legacy(
     databricks_config: DatabricksConfig,
     path: str,
     depth: int = 1,
@@ -380,7 +377,9 @@ def __get_childitem_old(
 
         for current_path in current_paths_filtered:
             if path[-1] == "/":
-                get_childitem(databricks_config, current_path, depth, verbose, i_depth)
+                get_childitems_legacy(
+                    databricks_config, current_path, depth, verbose, i_depth
+                )
 
 
 def get_views(databricks_config: DatabricksConfig, database_name: str):
@@ -845,12 +844,39 @@ def get_last_file_update(databricks_config: DatabricksConfig, entity: str) -> No
     print(f"    Last Modified: {max_mod_time}")
 
 
-def get_childitem(
+def get_childitems(
+    databricks_config: DatabricksConfig = None,
+    path: str = "",
+    depth: int = 1,
+) -> None:
+    """
+    A function for printing entity folders
+
+    Parameters
+    ----------
+    databricks_config : DatabricksConfig
+        A databricks config object
+
+    path : string
+        An entity path to query against
+
+    depth : int
+        The max number of child folders, to traverse
+    """
+
+    folders = __get_childitem_list(databricks_config, path, depth)
+
+    for folder in folders:
+        print(folder)
+
+
+def __get_childitem_list(
     databricks_config: DatabricksConfig,
     path: str,
     depth: int = 1,
-    __current_depth: int = 0,
-) -> None:
+    current_depth: int = 0,
+    string_array: List[str] = list(),
+) -> List[str]:
     """
     A function for printing entity folders
 
@@ -871,7 +897,10 @@ def get_childitem(
         return
 
     profile_alias = databricks_config.profile_alias
-    print_env(profile_alias)
+    if current_depth == 0:
+        print_env(profile_alias)
+        string_array.clear()
+        string_array.append(path)
 
     profile = __get_profile_name(profile_alias)
     configs = __read_files_profiles()
@@ -886,15 +915,26 @@ def get_childitem(
     }
     data = {"path": f"{path}"}
 
-    if __current_depth <= depth:
-        i_depth = __current_depth + 1
+    if current_depth < depth:
         resp = requests.get(url=uri, headers=headers, json=data)
-
         if resp.status_code == 200:
             text_resp = json.loads(resp.text)
             if "files" in text_resp:
                 for file in text_resp["files"]:
                     sub_path = file["path"]
                     if file["is_dir"]:
-                        print(sub_path.rjust(len(sub_path) + (__current_depth * 4)))
-                        get_childitem(databricks_config, sub_path, depth, i_depth)
+                        display_path = sub_path.rjust(
+                            len(sub_path) + ((1 + current_depth) * 4)
+                        )
+                        string_array.append(display_path)
+
+                        sub_depth = current_depth + 1
+                        if sub_depth < depth:
+                            __get_childitem_list(
+                                databricks_config,
+                                sub_path,
+                                depth,
+                                sub_depth,
+                            )
+
+                return string_array
